@@ -1,7 +1,7 @@
 package Bencher::Scenario::SetOperationModules;
 
 our $DATE = '2017-02-19'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -279,7 +279,7 @@ Bencher::Scenario::SetOperationModules - Benchmark Perl set operation (union, in
 
 =head1 VERSION
 
-This document describes version 0.11 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2017-02-19.
+This document describes version 0.12 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2017-02-19.
 
 =head1 SYNOPSIS
 
@@ -632,101 +632,151 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 Benchmark with default options (C<< bencher -m SetOperationModules >>):
 
  #table1#
- +---------------------------------------+---------+-----------+------------+------------+---------+---------+
- | participant                           | dataset | rate (/s) |  time (ms) | vs_slowest |  errors | samples |
- +---------------------------------------+---------+-----------+------------+------------+---------+---------+
- | Array::AsObject::symmetric_difference | num100  |     112.6 | 8.878      |      1     | 4.3e-07 |      20 |
- | Array::AsObject::intersection         | num100  |     230.2 | 4.343      |      2.044 |   2e-07 |      22 |
- | Array::AsObject::difference           | num100  |     470   | 2.13       |      4.17  | 2.6e-07 |      21 |
- | List::Collection::complement          | num100  |     561   | 1.78       |      4.98  | 9.1e-07 |      20 |
- | Set::Array::intersection              | num100  |     622   | 1.61       |      5.52  | 1.3e-06 |      20 |
- | List::Collection::union               | num100  |     940   | 1.1        |      8.4   | 1.2e-06 |      20 |
- | List::Collection::intersect           | num100  |    1400   | 0.71       |     12     | 1.1e-06 |      20 |
- | Set::Scalar::intersection             | num100  |    2020   | 0.495      |     17.9   | 2.7e-07 |      20 |
- | Set::Scalar::union                    | num100  |    2120   | 0.472      |     18.8   | 3.7e-07 |      20 |
- | Set::Scalar::difference               | num100  |    2230   | 0.449      |     19.8   | 4.2e-07 |      21 |
- | Set::Scalar::symmetric_difference     | num100  |    3010   | 0.332      |     26.7   | 2.1e-07 |      20 |
- | Array::AsObject::symmetric_difference | num10   |    5100   | 0.196      |     45.3   | 4.6e-08 |      27 |
- | List::Collection::complement          | num10   |    8100   | 0.12       |     72     | 6.9e-07 |      20 |
- | Set::Object::symmetric_difference     | num100  |   10000   | 0.1        |     88     | 1.3e-07 |      20 |
- | Set::Object::intersection             | num100  |   11300   | 0.0885     |    100     |   8e-08 |      20 |
- | Array::AsObject::union                | num100  |   11328.9 | 0.0882696  |    100.58  |   0     |      20 |
- | Array::AsObject::intersection         | num10   |   11500   | 0.0872     |    102     | 2.5e-08 |      23 |
- | Set::Scalar::intersection             | num10   |   12000   | 0.087      |    100     | 1.7e-07 |      31 |
- | Set::Scalar::union                    | num10   |   12000   | 0.0835     |    106     | 2.7e-08 |      20 |
- | Set::Scalar::difference               | num10   |   12500   | 0.0802     |    111     | 2.7e-08 |      20 |
- | Set::Array::difference                | num100  |   13200   | 0.076      |    117     | 2.5e-08 |      22 |
- | Set::Array::symmetric_difference      | num100  |   13000   | 0.076      |    120     | 7.8e-08 |      21 |
- | Set::Object::union                    | num100  |   14000   | 0.072      |    120     |   1e-07 |      21 |
- | Set::Object::difference               | num100  |   15000   | 0.069      |    130     | 1.1e-07 |      20 |
- | Set::Tiny::symmetric_difference       | num100  |   16000   | 0.061      |    140     | 1.1e-07 |      20 |
- | List::Collection::intersect           | num10   |   16000   | 0.061      |    150     | 9.7e-08 |      24 |
- | List::Collection::union               | num10   |   17000   | 0.06       |    150     | 4.5e-07 |      20 |
- | Set::Tiny::difference                 | num100  |   17400   | 0.0573     |    155     | 2.6e-08 |      21 |
- | Set::Tiny::union                      | num100  |   18000   | 0.057      |    160     | 1.1e-07 |      20 |
- | Set::Tiny::intersection               | num100  |   18000   | 0.055      |    160     | 1.1e-07 |      20 |
- | Set::Scalar::symmetric_difference     | num10   |   18800   | 0.0532     |    167     | 2.7e-08 |      20 |
- | Set::Array::union                     | num100  |   19100   | 0.0524     |    169     | 2.3e-08 |      28 |
- | Array::Set::set_intersect             | num100  |   21000   | 0.047      |    190     | 1.6e-07 |      27 |
- | Array::Set::set_symdiff               | num100  |   21200   | 0.0471     |    188     | 1.2e-08 |      25 |
- | Array::Set::set_union                 | num100  |   22057.6 | 0.0453358  |    195.83  |   0     |      23 |
- | Array::AsObject::difference           | num10   |   24076.9 | 0.0415336  |    213.758 |   0     |      20 |
- | Array::Utils::array_diff              | num100  |   26000   | 0.038      |    230     | 4.2e-08 |      33 |
- | List::MoreUtils::PP::singleton        | num100  |   27000   | 0.037      |    240     | 1.1e-08 |      30 |
- | Array::Set::set_diff                  | num100  |   28500   | 0.0351     |    253     | 1.2e-08 |      24 |
- | Array::Utils::array_minus             | num100  |   29000   | 0.035      |    250     | 1.9e-07 |      25 |
- | Array::Utils::intersect               | num100  |   29300   | 0.0342     |    260     | 1.3e-08 |      22 |
- | List::Collection::subtract            | num100  |   30400   | 0.0329     |    270     | 1.1e-08 |      30 |
- | List::MoreUtils::PP::uniq             | num100  |   35000   | 0.028      |    320     | 4.4e-08 |      29 |
- | Set::Array::intersection              | num10   |   37000   | 0.027      |    330     | 5.3e-08 |      20 |
- | List::MoreUtils::XS::singleton        | num100  |   43400   | 0.023      |    386     | 6.7e-09 |      20 |
- | List::MoreUtils::XS::uniq             | num100  |   56600   | 0.0177     |    502     | 5.4e-09 |      31 |
- | Set::Object::symmetric_difference     | num10   |   63800   | 0.0157     |    567     | 5.8e-09 |      26 |
- | Set::Array::difference                | num10   |   66800   | 0.015      |    593     | 6.7e-09 |      20 |
- | Set::Array::symmetric_difference      | num10   |   73000   | 0.014      |    650     | 2.5e-08 |      22 |
- | Array::AsObject::union                | num10   |   75000   | 0.013      |    670     | 2.2e-08 |      29 |
- | Set::Object::intersection             | num10   |   94000   | 0.011      |    840     | 1.3e-08 |      20 |
- | Set::Array::union                     | num10   |   95600   | 0.0105     |    848     | 3.1e-09 |      23 |
- | Set::Object::union                    | num10   |  110000   | 0.0089     |   1000     | 1.1e-08 |      27 |
- | Set::Object::difference               | num10   |  120000   | 0.0086     |   1000     | 1.2e-08 |      25 |
- | Set::Tiny::symmetric_difference       | num10   |  130000   | 0.0075     |   1200     |   1e-08 |      20 |
- | Set::Tiny::difference                 | num10   |  140000   | 0.007      |   1300     | 1.3e-08 |      20 |
- | Set::Tiny::union                      | num10   |  150000   | 0.0067     |   1300     | 1.3e-08 |      20 |
- | Set::Tiny::intersection               | num10   |  160000   | 0.0064     |   1400     | 1.3e-08 |      21 |
- | Array::Set::set_symdiff               | num10   |  179258   | 0.00557856 |   1591.47  |   0     |      20 |
- | Array::Set::set_union                 | num10   |  183000   | 0.00547    |   1620     | 1.4e-09 |      27 |
- | Array::Set::set_intersect             | num10   |  184430   | 0.0054221  |   1637.4   |   0     |      20 |
- | List::Collection::subtract            | num10   |  190000   | 0.00526    |   1690     | 1.3e-09 |      32 |
- | Array::Utils::array_diff              | num10   |  220000   | 0.00455    |   1950     | 1.7e-09 |      20 |
- | Array::Set::set_diff                  | num10   |  229376   | 0.00435965 |   2036.43  |   0     |      20 |
- | List::MoreUtils::PP::singleton        | num10   |  243262   | 0.0041108  |   2159.71  |   0     |      20 |
- | Array::Utils::unique                  | num100  |  260000   | 0.0038     |   2300     | 6.7e-09 |      20 |
- | Array::Utils::intersect               | num10   |  263305   | 0.00379788 |   2337.66  |   0     |      20 |
- | Array::Utils::array_minus             | num10   |  265000   | 0.00378    |   2350     | 3.8e-09 |      35 |
- | List::MoreUtils::PP::uniq             | num10   |  315256   | 0.00317203 |   2798.88  |   0     |      20 |
- | List::MoreUtils::XS::singleton        | num10   |  420000   | 0.0024     |   3700     | 2.5e-09 |      20 |
- | List::MoreUtils::XS::uniq             | num10   |  520000   | 0.00192    |   4610     | 8.3e-10 |      20 |
- | Array::Utils::unique                  | num10   |  850000   | 0.0012     |   7500     | 1.2e-09 |      20 |
- +---------------------------------------+---------+-----------+------------+------------+---------+---------+
+ {dataset=>"num10",p_tags=>"op:diff"}
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                 | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | Set::Scalar::difference     |     12000 |   80      |      1     | 1.3e-07 |      20 |
+ | Array::AsObject::difference |     24000 |   41.7    |      1.92  | 1.3e-08 |      20 |
+ | Set::Array::difference      |     67000 |   15      |      5.3   | 1.9e-08 |      22 |
+ | Set::Object::difference     |    114000 |    8.74   |      9.16  | 3.3e-09 |      20 |
+ | Set::Tiny::difference       |    141000 |    7.08   |     11.3   |   3e-09 |      24 |
+ | List::Collection::subtract  |    190000 |    5.3    |     15     | 6.7e-09 |      20 |
+ | Array::Set::set_diff        |    226000 |    4.42   |     18.1   | 1.7e-09 |      20 |
+ | Array::Utils::array_minus   |    263070 |    3.8013 |     21.053 | 2.9e-11 |      21 |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+
+ #table2#
+ {dataset=>"num100",p_tags=>"op:diff"}
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                 | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | Array::AsObject::difference |       460 |    2.2    |        1   | 4.2e-06 |      21 |
+ | Set::Scalar::difference     |      2200 |    0.46   |        4.7 | 2.4e-06 |      21 |
+ | Set::Array::difference      |     13000 |    0.078  |       28   | 4.2e-07 |      21 |
+ | Set::Object::difference     |     15000 |    0.068  |       32   |   8e-08 |      20 |
+ | Set::Tiny::difference       |     17000 |    0.058  |       37   | 1.1e-07 |      20 |
+ | Array::Set::set_diff        |     29000 |    0.035  |       62   | 5.3e-08 |      20 |
+ | Array::Utils::array_minus   |     30000 |    0.034  |       64   | 5.3e-08 |      20 |
+ | List::Collection::subtract  |     29600 |    0.0338 |       64.5 |   1e-08 |      34 |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+
+ #table3#
+ {dataset=>"num10",p_tags=>"op:intersect"}
+ +-------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                   | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +-------------------------------+-----------+-----------+------------+---------+---------+
+ | Set::Scalar::intersection     |     11000 |  90       |     1      | 1.1e-07 |      30 |
+ | Array::AsObject::intersection |     11000 |  90       |     1      |   1e-07 |      22 |
+ | List::Collection::intersect   |     18000 |  55       |     1.6    | 9.7e-08 |      24 |
+ | Set::Array::intersection      |     36000 |  28       |     3.3    | 3.7e-08 |      24 |
+ | Set::Object::intersection     |     91400 |  10.9     |     8.21   | 3.3e-09 |      20 |
+ | Set::Tiny::intersection       |    155572 |   6.42789 |    13.9869 |   0     |      38 |
+ | Array::Set::set_intersect     |    176000 |   5.69    |    15.8    | 1.6e-09 |      22 |
+ | Array::Utils::intersect       |    249390 |   4.0098  |    22.422  | 2.3e-11 |      20 |
+ +-------------------------------+-----------+-----------+------------+---------+---------+
+
+ #table4#
+ {dataset=>"num100",p_tags=>"op:intersect"}
+ +-------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                   | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-------------------------------+-----------+-----------+------------+---------+---------+
+ | Array::AsObject::intersection |       223 |    4.48   |       1    | 2.5e-06 |      20 |
+ | Set::Array::intersection      |       595 |    1.68   |       2.66 | 1.1e-06 |      20 |
+ | List::Collection::intersect   |      1400 |    0.73   |       6.2  | 2.2e-06 |      20 |
+ | Set::Scalar::intersection     |      1980 |    0.505  |       8.87 | 2.1e-07 |      20 |
+ | Set::Object::intersection     |     11000 |    0.092  |      49    | 1.1e-07 |      27 |
+ | Set::Tiny::intersection       |     18000 |    0.056  |      80    |   1e-07 |      21 |
+ | Array::Set::set_intersect     |     20800 |    0.0482 |      92.9  | 1.3e-08 |      22 |
+ | Array::Utils::intersect       |     27900 |    0.0358 |     125    | 1.1e-08 |      28 |
+ +-------------------------------+-----------+-----------+------------+---------+---------+
+
+ #table5#
+ {dataset=>"num10",p_tags=>"op:symdiff"}
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                           | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
+ | Array::AsObject::symmetric_difference |    5110   |  196      |     1      | 4.9e-08 |      24 |
+ | List::Collection::complement          |    7900   |  130      |     1.5    | 6.9e-07 |      20 |
+ | Set::Scalar::symmetric_difference     |   19000   |   53      |     3.7    | 1.3e-07 |      21 |
+ | Set::Object::symmetric_difference     |   62900   |   15.9    |    12.3    | 6.1e-09 |      24 |
+ | Set::Array::symmetric_difference      |   73714.5 |   13.5659 |    14.4262 |   0     |      20 |
+ | Set::Tiny::symmetric_difference       |  130000   |    7.6    |    26      | 1.3e-08 |      20 |
+ | Array::Set::set_symdiff               |  173400   |    5.767  |    33.93   | 9.8e-11 |      21 |
+ | Array::Utils::array_diff              |  216300   |    4.622  |    42.34   | 1.9e-10 |      22 |
+ | List::MoreUtils::PP::singleton        |  235000   |    4.25   |    46.1    | 1.5e-09 |      26 |
+ | List::MoreUtils::XS::singleton        |  414000   |    2.41   |    81.1    | 7.5e-10 |      25 |
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
+
+ #table6#
+ {dataset=>"num100",p_tags=>"op:symdiff"}
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                           | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
+ | Array::AsObject::symmetric_difference |       110 |    9.3    |          1 | 2.8e-05 |      20 |
+ | List::Collection::complement          |       530 |    1.9    |          5 | 3.8e-06 |      20 |
+ | Set::Scalar::symmetric_difference     |      3000 |    0.34   |         28 | 6.1e-07 |      22 |
+ | Set::Object::symmetric_difference     |      9400 |    0.11   |         87 | 1.5e-07 |      24 |
+ | Set::Array::symmetric_difference      |     13300 |    0.0752 |        124 | 2.7e-08 |      20 |
+ | Set::Tiny::symmetric_difference       |     16000 |    0.063  |        150 | 9.9e-08 |      23 |
+ | Array::Set::set_symdiff               |     20800 |    0.0481 |        193 | 1.3e-08 |      20 |
+ | List::MoreUtils::PP::singleton        |     26200 |    0.0381 |        244 | 1.2e-08 |      25 |
+ | Array::Utils::array_diff              |     26700 |    0.0375 |        249 | 1.3e-08 |      20 |
+ | List::MoreUtils::XS::singleton        |     42800 |    0.0234 |        398 |   6e-09 |      25 |
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
+
+ #table7#
+ {dataset=>"num10",p_tags=>"op:union"}
+ +---------------------------+-----------+-----------+------------+---------+---------+
+ | participant               | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +---------------------------+-----------+-----------+------------+---------+---------+
+ | Set::Scalar::union        |     12000 |  85       |     1      | 1.3e-07 |      20 |
+ | List::Collection::union   |     17000 |  60       |     1.4    | 2.1e-07 |      21 |
+ | Array::AsObject::union    |     75100 |  13.3     |     6.38   | 6.7e-09 |      20 |
+ | Set::Array::union         |     97000 |  10       |     8.2    | 1.3e-08 |      20 |
+ | Set::Object::union        |    110000 |   8.9     |     9.5    | 1.3e-08 |      20 |
+ | Set::Tiny::union          |    150000 |   6.6     |    13      |   1e-08 |      20 |
+ | Array::Set::set_union     |    180000 |   5.5     |    16      | 6.7e-09 |      20 |
+ | List::MoreUtils::PP::uniq |    320000 |   3.2     |    27      | 6.7e-09 |      20 |
+ | List::MoreUtils::XS::uniq |    512740 |   1.95031 |    43.5071 |   0     |      24 |
+ | Array::Utils::unique      |    849000 |   1.18    |    72.1    | 4.2e-10 |      20 |
+ +---------------------------+-----------+-----------+------------+---------+---------+
+
+ #table8#
+ {dataset=>"num100",p_tags=>"op:union"}
+ +---------------------------+-----------+-----------+------------+---------+---------+
+ | participant               | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +---------------------------+-----------+-----------+------------+---------+---------+
+ | List::Collection::union   |       920 |  1100     |      1     | 2.2e-06 |      20 |
+ | Set::Scalar::union        |      2130 |   469     |      2.31  | 4.3e-07 |      20 |
+ | Array::AsObject::union    |     11000 |    91     |     12     |   3e-07 |      26 |
+ | Set::Object::union        |     14000 |    71     |     15     | 2.1e-07 |      20 |
+ | Set::Tiny::union          |     18000 |    57     |     19     | 1.1e-07 |      20 |
+ | Set::Array::union         |     18000 |    56     |     19     | 1.1e-07 |      20 |
+ | Array::Set::set_union     |     22168 |    45.111 |     24.076 | 5.8e-11 |      25 |
+ | List::MoreUtils::PP::uniq |     34600 |    28.9   |     37.6   | 1.2e-08 |      24 |
+ | List::MoreUtils::XS::uniq |     55900 |    17.9   |     60.7   | 5.8e-09 |      26 |
+ | Array::Utils::unique      |    260000 |     3.9   |    280     | 6.7e-09 |      20 |
+ +---------------------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m SetOperationModules --module-startup >>):
 
- #table2#
+ #table9#
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Set::Array          | 3                            | 6.5                | 26             |     14    |                  11.45 |       1    | 6.6e-05 |      21 |
- | List::Collection    | 0.93                         | 4.3                | 20             |     14    |                  11.45 |       1    | 2.4e-05 |      20 |
- | Array::AsObject     | 2.2                          | 5.6                | 23             |     14    |                  11.45 |       1    | 2.7e-05 |      20 |
- | Set::Object         | 1                            | 4.4                | 20             |     11    |                   8.45 |       1.3  | 2.1e-05 |      20 |
- | Set::Scalar         | 1.2                          | 4.5                | 20             |     10    |                   7.45 |       1.3  |   4e-05 |      20 |
- | List::MoreUtils     | 1.1                          | 4.5                | 20             |      8.1  |                   5.55 |       1.7  | 2.9e-05 |      20 |
- | List::MoreUtils::PP | 1.6                          | 5.1                | 23             |      5.6  |                   3.05 |       2.5  | 2.4e-05 |      20 |
- | Array::Set          | 2.7                          | 6.1                | 28             |      5.1  |                   2.55 |       2.7  | 2.6e-05 |      20 |
- | Set::Tiny           | 2.3                          | 5.8                | 27             |      3.7  |                   1.15 |       3.7  | 8.5e-06 |      20 |
- | Array::Utils        | 1.9                          | 5.3                | 23             |      3.6  |                   1.05 |       3.9  | 2.9e-05 |      20 |
- | perl -e1 (baseline) | 0.934                        | 4.34               | 20             |      2.55 |                   0    |       5.48 |   2e-06 |      20 |
+ | List::Collection    | 0.93                         | 4.3                | 20             |      14   |                   11.4 |        1   | 3.3e-05 |      20 |
+ | Set::Array          | 3                            | 6.5                | 26             |      14   |                   11.4 |        1   | 6.6e-05 |      20 |
+ | Array::AsObject     | 2.2                          | 5.6                | 23             |      14   |                   11.4 |        1   | 5.9e-05 |      20 |
+ | Set::Object         | 1                            | 4.4                | 20             |      12   |                    9.4 |        1.2 | 2.7e-05 |      20 |
+ | Set::Scalar         | 1.2                          | 4.5                | 20             |      11   |                    8.4 |        1.3 | 3.2e-05 |      20 |
+ | List::MoreUtils     | 1.1                          | 4.4                | 20             |       8.4 |                    5.8 |        1.7 |   5e-05 |      20 |
+ | List::MoreUtils::PP | 1.6                          | 5                  | 23             |       5.7 |                    3.1 |        2.5 | 3.2e-05 |      20 |
+ | Array::Set          | 2.7                          | 6.1                | 28             |       5.2 |                    2.6 |        2.8 | 2.7e-05 |      20 |
+ | Set::Tiny           | 2.3                          | 5.7                | 27             |       3.8 |                    1.2 |        3.8 | 1.7e-05 |      20 |
+ | Array::Utils        | 1.9                          | 5.3                | 23             |       3.7 |                    1.1 |        3.9 | 2.2e-05 |      20 |
+ | perl -e1 (baseline) | 0.93                         | 4.3                | 20             |       2.6 |                    0   |        5.6 | 6.5e-06 |      20 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
